@@ -1,8 +1,8 @@
 import pathlib
 
-from . import decluster, modeling
+from . import decluster, modeling, stats, utils
 from ._catalog import Catalog
-from ._helpers import from_csep, to_decimal_year
+from ._helpers import from_csep, set_seed
 
 with open(f"{pathlib.Path(__file__).parent}/VERSION") as f:
     __version__ = f.readline().strip()
@@ -12,7 +12,9 @@ __all__ = [
     "Catalog",
     "decluster",
     "modeling",
+    "stats",
+    "utils",
     "from_csep",
-    "to_decimal_year",
+    "set_seed",
     "__version__",
 ]
