@@ -48,7 +48,7 @@ def decluster(catalog, algorithm="nearest-neighbor", return_indices=False, **kwa
         Only if ``algorithm = "nearest-neighbor"``. Cluster threshold.
     use_depth : bool, optional, default False
         Only if ``algorithm = "nearest-neighbor"``. If `True`, consider depth in interevent distance calculation.
-    M : int, optional, default 100
+    M : int, optional, default 16
         Only if ``algorithm = "nearest-neighbor"``. Number of reshufflings.
     seed : int or None, optional, default None
         Only if ``algorithm = "nearest-neighbor"``. Seed for random number generator.
@@ -58,10 +58,10 @@ def decluster(catalog, algorithm="nearest-neighbor", return_indices=False, **kwa
         Only if ``algorithm = "reasenberg"``. "Effective" lower magnitude cutoff for catalog. If `None`, use minimum magnitude in catalog.
     xk : scalar, optional, default 0.5
         Only if ``algorithm = "reasenberg"``. Factor by which ``xmeff`` is raised during clusters.
-    taumin : scalar, optional, default 1.0
-        Only if ``algorithm = "reasenberg"``. Look ahead time for non-clustered events (in days).
-    taumax : scalar, optional, default 10.0
-        Only if ``algorithm = "reasenberg"``. Maximum look ahead time for clustered events (in days).
+    tau_min : scalar, timedelta_like or None, optional, default None
+        Only if ``algorithm = "reasenberg"``. Look ahead time for non-clustered events (in days if scalar). Default is 1 day.
+    tau_max : tau_min : scalar, timedelta_like or None, optional, default None
+        Only if ``algorithm = "reasenberg"``. Maximum look ahead time for clustered events (in days if scalar). Default is 10 days.
     p : scalar, optional, default 0.95
         Only if ``algorithm = "reasenberg"``. Confidence of observing the next event in the sequence.
 
