@@ -1,8 +1,10 @@
+from ._etas import etas
 from ._magnitude_time import magnitude_time
 from ._seismicity_rate import seismicity_rate
 from ._seismogram import seismogram
 
 __all__ = [
+    "etas",
     "magnitude_time",
     "seismicity_rate",
     "seismogram",
